@@ -17,7 +17,7 @@ theDonors.append(('Bilateral Cooperations','Bilateral Cooperations'))
 theDonors.append(('--- All','All Bilateral Cooperations'))
 theDonors.append(('--- Afghanistan','Afghanistan'))
 theDonors.append(('------- Afghan Government','Afghan Government'))
-theDonors.append(('------- Ministry of Agriculture, Irrigation and Livestock (MAIL)','Ministry of Agriculture, Irrigation and Livestock(MAIL)'))
+theDonors.append(('------- Ministry of Agriculture, Irrigation and Livestock (MAIL)','Ministry of Agriculture, Irrigation and Livestock (MAIL)'))
 theDonors.append(('------- Ministry of Social Affairs','Ministry of Social Affairs'))
 theDonors.append(('------- Minister of Counter Narcotics','Minister of Counter Narcotics'))
 theDonors.append(('------- Other:','Other Afghanistan'))
@@ -33,7 +33,7 @@ theDonors.append(('--- DRC','DRC'))
 theDonors.append(('--- France','France'))
 theDonors.append(('------- CIAA','CIAA'))
 theDonors.append(('------- Centre de Crise/DAH','Centre de Crise/DAH'))
-theDonors.append(('------- Decentralised Cooperation:','Decentralised Cooperation:'))
+theDonors.append(('------- Decentralised Cooperation','Decentralised Cooperation'))
 theDonors.append(('----------- Cités Unies France','Cités Unies France'))
 theDonors.append(('----------- Ville de Paris','Ville de Paris'))
 theDonors.append(('----------- Other:','Other France Decentralised Cooperation'))
@@ -72,7 +72,7 @@ theDonors.append(('--- Spain','Spain'))
 theDonors.append(('------- AECID','AECID'))
 theDonors.append(('--- Sweden','Sweden'))
 theDonors.append(('------- SIDA','SIDA'))
-theDonors.append(('--- Switzerland:','Switzerland:'))
+theDonors.append(('--- Switzerland','Switzerland'))
 theDonors.append(('------- SDC/DDC','SDC/DDC'))
 theDonors.append(('--- Tajikistan ','Tajikistan'))
 theDonors.append(('--- Turkey','Turkey'))
@@ -96,16 +96,16 @@ theDonors.append(('--- ECHO','ECHO'))
 theDonors.append(('--- EuropeAid (AidCo)','EuropeAid (AidCo)'))
 theDonors.append(('--- Other:','Other European Commission'))
 theDonors.append(('------- Euronaid','Euronaid'))
-theDonors.append(('------- Task Force','TaskForce'))
+theDonors.append(('------- Task Force','Task Force'))
 theDonors.append(('International Organisations','International Organisations'))
 theDonors.append(('--- All','All'))
 theDonors.append(('--- ADB/BAD','ADB/BAD'))
 theDonors.append(('--- ASEAN','ASEAN'))
 theDonors.append(('--- EBRD/BERD','EBRD/BERD'))
 theDonors.append(('--- Global Fund','Global Fund'))
-theDonors.append(('--- IOM/OIM','IOM/OIM'))
+theDonors.append(('--- IOM / OIM','IOM / OIM'))
 theDonors.append(('--- OSCE','OSCE'))
-theDonors.append(('------- WB/BM','WB/BM'))
+theDonors.append(('------- WB / BM','WB / BM'))
 theDonors.append(('----------- MISFA','MISFA'))
 theDonors.append(('----------- NSP','NSP'))
 theDonors.append(('----------- Other','Other WB/BM'))
@@ -113,7 +113,7 @@ theDonors.append(('--- Other','Other International Organisations'))
 theDonors.append(('Private Cooperation','Private Cooperation'))
 theDonors.append(('--- All','All'))
 theDonors.append(('--- ABN-AMRO','ABN-AMRO'))
-theDonors.append(('--- Aga Khan Foundation','AgaKhan Foundation'))
+theDonors.append(('--- Aga Khan Foundation','Aga Khan Foundation'))
 theDonors.append(('--- Assistance Foundation','Assistance Foundation'))
 theDonors.append(('--- Association Enfants Démunis Kareen Mane (AED)','Association Enfants Démunis Kareen Mane (AED)'))
 theDonors.append(('--- CARE','CARE'))
@@ -123,28 +123,28 @@ theDonors.append(('--- Chemonics','Chemonics'))
 theDonors.append(('--- Cooperative Housing Foundation (CHF)','Cooperative Housing Foundation (CHF)'))
 theDonors.append(('--- Children Aid','Children Aid'))
 theDonors.append(('--- Christian Aid','Christian Aid'))
-theDonors.append(('--- Clinton Foundation','ClintonFoundation'))
+theDonors.append(('--- Clinton Foundation','Clinton Foundation'))
 theDonors.append(('--- Concern','Concern'))
-theDonors.append(('--- DanChurch Aid (DCA)','DanChurchAid(DCA)'))
-theDonors.append(('--- Eurasian Foundation of Central Asia','EurasianFoundationofCentralAsia'))
-theDonors.append(('--- Family Health International','FamilyHealthInternational'))
-theDonors.append(('--- Fondation de France','FondationdeFrance'))
-theDonors.append(('--- France Culture','FranceCulture'))
+theDonors.append(('--- Dan Church Aid (DCA)','Dan Church Aid (DCA)'))
+theDonors.append(('--- Eurasian Foundation of Central Asia','Eurasian Foundation of Central Asia'))
+theDonors.append(('--- Family Health International','Family Health International'))
+theDonors.append(('--- Fondation de France','Fondation de France'))
+theDonors.append(('--- France Culture','France Culture'))
 theDonors.append(('--- GTZ','GTZ'))
 theDonors.append(('--- HIVOS','HIVOS'))
 theDonors.append(('--- Interchurch Organisation for Development Cooperation (ICCO)','Interchurch Organisation for Development Cooperation (ICCO)'))
 theDonors.append(('--- International Rescue Committee (IRC)','International Rescue Committee (IRC)'))
 theDonors.append(('--- Musée Guimet','Musée Guimet'))
-theDonors.append(('--- Norwegian Church Aid/ Norwegian Refugee Council (NCA / NRC)','Norwegian ChurchAid/Norwegian Refugee Council (NCA/NRC)'))
+theDonors.append(('--- Norwegian Church Aid / Norwegian Refugee Council (NCA / NRC)','Norwegian Church Aid / Norwegian Refugee Council (NCA/NRC)'))
 theDonors.append(('--- Novib','Novib'))
-theDonors.append(('--- People In Need (PIN)','People In Need(PIN)'))
-theDonors.append(('--- Red Cross/Croix Rouge /IFRC/FICR','Red Cross/Croix Rouge/IFRC/FICR'))
+theDonors.append(('--- People In Need (PIN)','People In Need (PIN)'))
+theDonors.append(('--- Red Cross / Croix Rouge / IFRC / FICR','Red Cross / Croix Rouge / IFRC / FICR'))
 theDonors.append(('--- Reuters','Reuters'))
 theDonors.append(('--- ShelterBox UK','ShelterBox UK'))
 theDonors.append(('--- Soros Foundation','Soros Foundation'))
-theDonors.append(('--- The Christensen Fund (TCF)','The Christensen Fund(TCF)'))
+theDonors.append(('--- The Christensen Fund (TCF)','The Christensen Fund (TCF)'))
 theDonors.append(('--- United Methodist Committee on Relief (UMCOR)','United Methodist Committeeon Relief (UMCOR)'))
-theDonors.append(('--- Voix de l\’Enfant (VDE)','Voix de l\’Enfant (VDE)'))
+theDonors.append(('--- Voix de l\'Enfant (VDE)','Voix de l\'Enfant (VDE)'))
 theDonors.append(('--- Vétérinaires Sans Frontières-Belgium (VSF)','Vétérinaires Sans Frontières-Belgium (VSF)'))
 theDonors.append(('--- Warchild','Warchild'))
 theDonors.append(('--- Welthungerhilfe (WHH)','Welthungerhilfe (WHH)'))
@@ -172,17 +172,17 @@ theDonors.append(('United Nations','United Nations'))
 theDonors.append(('--- All','All'))
 theDonors.append(('--- FAO','FAO'))
 theDonors.append(('--- UN Habitat','UN Habitat'))
-theDonors.append(('--- UNDP/PNUD','UNDP/PNUD'))
+theDonors.append(('--- UNDP / PNUD','UNDP / PNUD'))
 theDonors.append(('--- UNESCO','UNESCO'))
 theDonors.append(('--- UNHCR','UNHCR'))
 theDonors.append(('--- UNICEF','UNICEF'))
 theDonors.append(('--- UNOCHA','UNOCHA'))
-theDonors.append(('--- WFP/PAM','WFP/PAM'))
-theDonors.append(('--- WHO/OMS','WHO/OMS'))
+theDonors.append(('--- WFP / PAM','WFP / PAM'))
+theDonors.append(('--- WHO / OMS','WHO / OMS'))
 theDonors.append(('--- Other:','Other United Nations'))
 theDonors.append(('------- MINUSTAH','MINUSTAH'))
 theDonors.append(('------- MONUC','MONUC'))
-theDonors.append(('------- Pooled Fund','PooledFund'))
+theDonors.append(('------- Pooled Fund','Pooled Fund'))
 theDonors.append(('------- UNAMA','UNAMA'))
 theDonors.append(('------- UNDEF','UNDEF'))
 theDonors.append(('------- UNFPA','UNFPA'))
@@ -272,4 +272,5 @@ for year in theYears:
 PROJECTNAME = 'acted.projects'
 ADD_PERMISSIONS = {
     'ACTEDProject': 'acted.projects: Add ACTED Project',
+    'MyMut': 'acted.projects: Add ACTED Project',
 }
